@@ -262,7 +262,7 @@ fn migrations_to_tempdb(migrations: &[String]) -> Connection {
 
  tempdb
   .execute_batch(
-   "CREATE TABLE _turbosql_migrations (rowid INTEGER PRIMARY KEY, migration TEXT NOT NULL);",
+   "CREATE TABLE _turbosql_migrations (rowid INTEGER PRIMARY KEY, migration TEXT NOT NULL) STRICT;",
   )
   .unwrap();
 
@@ -738,6 +738,7 @@ pub fn turbosql_derive_macro(input: proc_macro::TokenStream) -> proc_macro::Toke
  // output tokenstream
 
  proc_macro::TokenStream::from(quote! {
+  #[cfg(not(target_arch = "wasm32"))]
   impl #table {
    #fn_insert
    #fn_update
@@ -786,7 +787,6 @@ fn extract_columns(fields: &FieldsNamed) -> Vec<Column> {
 
    let sql_type = match (name.as_str(), ty_str.as_str()) {
     ("rowid", "Option < i64 >") => "INTEGER PRIMARY KEY",
-    ("rowid", "Option < i54 >") => "INTEGER PRIMARY KEY",
     // (_, "i64") => "INTEGER NOT NULL",
     (_, "Option < i8 >") => "INTEGER",
     (_, "Option < u8 >") => "INTEGER",
@@ -794,7 +794,6 @@ fn extract_columns(fields: &FieldsNamed) -> Vec<Column> {
     (_, "Option < u16 >") => "INTEGER",
     (_, "Option < i32 >") => "INTEGER",
     (_, "Option < u32 >") => "INTEGER",
-    (_, "Option < i54 >") => "INTEGER",
     (_, "Option < i64 >") => "INTEGER",
     (_, "u64") => abort!(ty, SQLITE_U64_ERROR),
     (_, "Option < u64 >") => abort!(ty, SQLITE_U64_ERROR),
@@ -802,7 +801,7 @@ fn extract_columns(fields: &FieldsNamed) -> Vec<Column> {
     (_, "Option < f64 >") => "REAL",
     (_, "Option < f32 >") => "REAL",
     // (_, "bool") => "BOOLEAN NOT NULL",
-    (_, "Option < bool >") => "BOOLEAN",
+    (_, "Option < bool >") => "INTEGER",
     // (_, "String") => "TEXT NOT NULL",
     (_, "Option < String >") => "TEXT",
     // SELECT LENGTH(blob_column) ... will be null if blob is null
@@ -934,14 +933,14 @@ fn create(table: &Table) {
 
 fn makesql_create(table: &Table) -> String {
  format!(
-  "CREATE TABLE {} ({})",
+  "CREATE TABLE {} ({}) STRICT",
   table.name,
   table.columns.iter().map(|c| format!("{} {}", c.name, c.sql_type)).collect::<Vec<_>>().join(",")
  )
 }
 
 fn make_migrations(table: &Table) -> Vec<String> {
- let mut vec = vec![format!("CREATE TABLE {} (rowid INTEGER PRIMARY KEY)", table.name)];
+ let mut vec = vec![format!("CREATE TABLE {} (rowid INTEGER PRIMARY KEY) STRICT", table.name)];
 
  let mut alters = table
   .columns
